@@ -297,6 +297,7 @@ types: list[str] = [
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -327,6 +328,7 @@ types: list[str] = [
     "AWS::EMRContainers::VirtualCluster",
     "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
+    "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
@@ -538,6 +540,7 @@ types: list[str] = [
     "AWS::NetworkManager::CoreNetwork",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::DirectConnectGatewayAttachment",
     "AWS::NetworkManager::GlobalNetwork",
     "AWS::NetworkManager::Link",
     "AWS::NetworkManager::LinkAssociation",
@@ -789,7 +792,6 @@ cached: list[str] = [
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -800,10 +802,12 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -858,6 +862,8 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-ce-anomalymonitor.json",
+    "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-certificate.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
@@ -1028,7 +1034,6 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
-    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -1047,6 +1052,7 @@ cached: list[str] = [
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
@@ -1054,7 +1060,6 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
-    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1068,6 +1073,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1105,6 +1111,7 @@ cached: list[str] = [
     "aws-eventschemas-registrypolicy.json",
     "aws-eventschemas-schema.json",
     "aws-fms-notificationchannel.json",
+    "aws-fms-policy.json",
     "aws-fms-resourceset.json",
     "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-filesystem.json",
@@ -1220,6 +1227,7 @@ cached: list[str] = [
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1244,6 +1252,7 @@ cached: list[str] = [
     "aws-mediapackagev2-channel.json",
     "aws-mediapackagev2-channelgroup.json",
     "aws-mediapackagev2-channelpolicy.json",
+    "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-mediatailor-channel.json",
     "aws-mediatailor-channelpolicy.json",
@@ -1272,6 +1281,7 @@ cached: list[str] = [
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
