@@ -156,6 +156,7 @@ types: list[str] = [
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::IntelligentPromptRouter",
     "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
@@ -363,11 +364,13 @@ types: list[str] = [
     "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
     "AWS::DataZone::Environment",
     "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
     "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
     "AWS::DataZone::Project",
     "AWS::DataZone::ProjectMembership",
     "AWS::DataZone::SubscriptionTarget",
@@ -503,6 +506,7 @@ types: list[str] = [
     "AWS::ECR::PublicRepository",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -1206,6 +1210,7 @@ types: list[str] = [
     "AWS::SSMContacts::ContactChannel",
     "AWS::SSMContacts::Plan",
     "AWS::SSMContacts::Rotation",
+    "AWS::SSMGuiConnect::Preferences",
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
